#
# spec file for package libcaca
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libcaca
Version:        0.99.beta20
Release:        3.3
Summary:        Library for Colour ASCII Art, text mode graphics
License:        WTFPL
Group:          Development/Languages/C and C++
URL:            http://caca.zoy.org
Source0:        https://github.com/cacalabs/%{name}/releases/download/v%{version}/%{name}-%{version}.tar.gz
Source1:        baselibs.conf
Patch0:         %{name}-X11_test.patch
Patch1:         %{name}-ruby_am_cflags.patch
Patch2:         %{name}-ruby_vendor_install.patch
Patch3:         %{name}-0.99.beta16-missing-GLU.patch
Patch4:         caca-no-build-date.patch
Patch5:         %{name}-0.99-texbuild.patch
Patch6:         %{name}-ncurses6.patch
Patch7:         Bug1143286_libcaca_configure_ac_chg_for_lto.patch
Patch8:         bsc1184751-add-space-for-NUL-byte.patch
Patch9:         bsc1197028-correctly-handle-zero-width-or-height-images.patch
Patch10:        %{name}-autoconf-2.69.patch
Patch11:        %{name}-0.99.beta20-gcc14.patch
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  freeglut-devel
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  ncurses-devel
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  python3-setuptools
BuildRequires:  ruby-devel
BuildRequires:  pkgconfig(ftgl)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(imlib2)
BuildRequires:  pkgconfig(slang)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(zlib)

%description
libcaca is the Colour AsCii Art library. It provides high level
functions for colour text drawing, simple primitives for line, polygon
and ellipse drawing, as well as powerful image to text conversion
routines.

%package -n %{name}0
Summary:        Library for Colour ASCII Art, text mode graphics
Group:          Development/Languages/C and C++
Provides:       %{name} = %{version}
Obsoletes:      %{name} < %{version}

%description -n libcaca0
libcaca is the Colour AsCii Art library. It provides high level
functions for colour text drawing, simple primitives for line, polygon
and ellipse drawing, as well as powerful image to text conversion
routines.

%package devel
Summary:        Library for Colour ASCII Art, text mode graphics
Group:          Development/Languages/C and C++
Requires:       %{name} = %{version}
Requires:       %{name}0-plugins = %{version}

%description devel
This package contains the header files and static libraries needed to
compile applications or shared objects that use libcaca.

%package -n python3-caca
Summary:        Python3 support for %{name}
Group:          Development/Languages/Python
Requires:       %{name} = %{version}
BuildArch:      noarch

%description -n python3-caca
This package contains all that is needed to use libcaca from python3.

%package -n libcaca0-plugins
Summary:        Plugins for %{name}
Group:          Development/Languages/C and C++
Requires:       %{name} = %{version}

%description -n libcaca0-plugins
This package contains gl and x11 plugins for caca.

%package ruby
Summary:        Ruby bindings for %{name}
Group:          Development/Languages/Ruby
Requires:       %{name} = %{version}
Requires:       ruby

%description ruby
All that is needed to use libcaca from ruby code.

%package -n caca-utils
Summary:        Colour ASCII Art Text mode graphics utilities based on libcaca
Group:          Amusements/Toys/Graphics
Requires:       imlib2-loaders
Requires:       toilet

%description -n caca-utils
This package contains utilities and demonstration programs for libcaca,
the Colour AsCii Art library.

cacaview is a simple image viewer for the terminal. It opens most image
formats such as JPEG, PNG, GIF etc. and renders them on the terminal
using ASCII art. The user can zoom and scroll the image, set the
dithering method or enable anti-aliasing.

cacaball is a tiny graphic program that renders animated ASCII
metaballs on the screen, cacafire is a port of AALib's aafire and
displays burning ASCII art flames, and cacademo is a simple application
that shows the libcaca rendering features such as line and ellipses
drawing, triangle filling and sprite blitting.

%prep
%autosetup -p1
RUBY="ruby-`echo %{rb_ver} | sed 's|\.[^\.]*$||'`"
find . -type f -exec sed -i "s|ruby-1.9|$RUBY|" \{\} \;
pushd python
#Change python script headers to python3
for i in `grep -rl "/usr/bin/env python"`;do sed -i '1s/^#!.*/#!\/usr\/bin\/python3/' ${i} ;done
popd

%build
autoreconf -fvi
export CFLAGS="$CFLAGS %{optflags} -I../caca/"
export CXXFLAGS="$CXXFLAGS %{optflags}"
%configure \
    --enable-slang \
    --enable-ncurses \
    --enable-x11 \
    --enable-imlib2 \
    --enable-gl \
    --enable-csharp=no \
    --enable-doc \
    --enable-shared=yes \
    --enable-static=no \
    --enable-conio=no \
    --enable-plugins \
    --enable-java=no \
    --enable-python
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%fdupes -s %{buildroot}%{_mandir}/
%fdupes -s %{buildroot}%{python3_sitelib}

%post -n libcaca0 -p /sbin/ldconfig
%postun -n libcaca0 -p /sbin/ldconfig
%post -n libcaca0-plugins -p /sbin/ldconfig
%postun -n libcaca0-plugins -p /sbin/ldconfig

%files -n libcaca0
%doc AUTHORS NEWS NOTES README THANKS
%license COPYING
%{_libdir}/*.so.*

%files devel
%{_datadir}/doc/libcaca-dev
%dir %{_libdir}/caca
%{_libdir}/*.so
%{_libdir}/caca/libx11_plugin.so
%{_libdir}/caca/libgl_plugin.so
%{_bindir}/caca-config
%{_libdir}/pkgconfig/*.pc
%{_includedir}/*
%{_mandir}/man1/caca-config.1%{?ext_man}
%{_mandir}/man3/*

%files ruby
%{rb_vendorarch}/*
%{rb_vendorlib}/caca.rb

%files -n python3-caca
%{python3_sitelib}/*

%files -n libcaca0-plugins
%dir %{_libdir}/caca
%{_libdir}/caca/libgl_plugin.so.0
%{_libdir}/caca/libgl_plugin.so.0.0.0
%{_libdir}/caca/libx11_plugin.so.0
%{_libdir}/caca/libx11_plugin.so.0.0.0

%files -n caca-utils
%{_bindir}/cacademo
%{_bindir}/cacafire
%{_bindir}/cacaview
%{_bindir}/cacaplay
%{_bindir}/cacaclock
%{_bindir}/cacaserver
%{_bindir}/img2txt
%{_datadir}/%{name}
%{_mandir}/man1/cacademo.1%{?ext_man}
%{_mandir}/man1/cacafire.1%{?ext_man}
%{_mandir}/man1/cacaview.1%{?ext_man}
%{_mandir}/man1/cacaplay.1%{?ext_man}
%{_mandir}/man1/cacaserver.1%{?ext_man}
%{_mandir}/man1/img2txt.1%{?ext_man}

%changelog
* Mon Jun 17 2024 Илья Индиго <ilya@ilya.top>
- Updated spec-file with manual optimizations.
* Mon Jun 17 2024 Martin Jambor <mjambor@suse.com>
- Added file libcaca-0.99.beta20-gcc14.patch (boo#1225795).
* Fri Feb 23 2024 Valentin Lefebvre <valentin.lefebvre@suse.com>
- Use %%autosetup, prepare for RPM 4.20.
  * Rewrote patches so that they are applied uniformly via %%autosetup.
  * Correctly reorder the patches in specfile declaration.
* Mon Nov 14 2022 Valentin Lefebvre <valentin.lefebvre@suse.com>
- add patch [libcaca-autoconf-2.69.patch]
  * Don't force autoconf to be at version 2.71
* Mon Nov 14 2022 Valentin Lefebvre <valentin.lefebvre@suse.com>
- Upgrade to 0.99.beta20
  * IPv6 support in cacaserver
  * fixed a bug from 2004 that caused PDF documentation generation to fail
  * memory allocation functions are now more robust
  * numerous fixes for memory leaks and invalid memory accesses:
  * CVE-2021-30498
  * CVE-2021-30499
  * CVE-2021-3410
  * CVE-2018-20546
  * CVE-2018-20547
  * CVE-2018-20545
  * CVE-2018-20548
  * CVE-2018-20549
- Dropped upstream fixed patches
  * libcaca-bsc1182731-prevent-overflow.patch
  * libcaca-variable-type.patch
  * Bug1120502-add_cast_to_prevent_overflow.patch
* Mon Mar 14 2022 Josef Möllers <josef.moellers@suse.com>
- When a zero-width or zero-height image is given, a divide-by-zero
  occurs. This patch checks for this and produces a zero-sized
  output.
  [bsc1197028-correctly-handle-zero-width-or-height-images.patch,
  CVE-2022-0856, bsc#1197028]
* Fri Apr 16 2021 Josef Möllers <josef.moellers@suse.com>
- The problem is due to the fact that the images in the POC have
  a size of 0x0 and thus, when exporting, no data is written for
  the image bits.
  However, space is allocated for the header only, not taking
  into account that sprintf appends a NUL byte.
  [CVE-2021-30498, CVE-2021-30499, bsc#1184751, bsc#1184752,
  bsc1184751-add-space-for-NUL-byte.patch]
* Fri Feb 26 2021 Josef Möllers <josef.moellers@suse.com>
- More overflow prevention of multiplying large ints
  [bsc#1182731, CVE-2021-3410, libcaca-bsc1182731-prevent-overflow.patch]
* Tue Mar 10 2020 Josef Möllers <josef.moellers@suse.com>
- The contents of libcaca-prevent-overflow.patch
  have been moved to Bug1120502-add_cast_to_prevent_overflow.patch
  and libcaca-variable-type.patch
  [libcaca-prevent-overflow.patch]
* Wed Feb 26 2020 Илья Индиго <ilya@ilya.top>
- Refreshed spec-file via spec-cleaner.
- Added Requires:toilet for caca-utils, because need for cacaclock.
* Thu Aug  1 2019 Michel Normand <normand@linux.vnet.ibm.com>
- Add Bug1143286_libcaca_configure_ac_chg_for_lto.patch
  bypass boo#1143286
* Mon Jan 21 2019 josef.moellers@suse.com
- Cast intermediate results to 64 bits to prevent overflow of
  calculations with 32-bit quentities.
  [CVE-2018-20544, bsc#1120502,
  Bug1120502-add_cast_to_prevent_overflow.patch]
* Mon Jan 21 2019 josef.moellers@suse.com
- Fix the size of width and height to be of size_t rather than
  int in struct caca_dither. Re-using existing patch.
  [CVE-2018-20546, bsc#1120503, CVE-2018-20547,
  bsc#1120504, libcaca-variable-type.patch]
* Tue Jan 15 2019 josef.moellers@suse.com
- Fix the size of width and height to be of size_t rather than
  unsigned int which may be too small on 64 bit architectures.
  This fixes three CVS and associated bugs.
  [CVE-2018-20545, bsc#1120584, CVE-2018-20548, bsc#1120589,
  CVE-2018-20549, bsc#1120470, libcaca-variable-type.patch]
* Tue Jan 30 2018 davejplater@gmail.com
- Deleted _service and use spec file to download git version.
- Shorten version field to joliet usable length.
- Change python headers to allow bindings to build normally with
  python3.
- Use %%license for license document.
* Tue Jan 23 2018 tchvatal@suse.com
- Drop the py2 bindings they fail to build using rpm macros and
  somehow ingnore LD_LIBRARY_PATH, anyway provide py3 variant and
  stick with that
* Tue Jan 23 2018 tchvatal@suse.com
- Switch to git repack service in order to get all the latest fixes
  * like python3 porting of the bindings
- Update to version 0.99.beta19+git20171002.da28e96:
  * img2text.c: fix width arg case in example
  * ruby: require 'caca' instead of 'caca.so'
  * Only fail the check-copyright test if more than 10 files are affected.
  * Try to run Coverity from Travis CI.
  * Add some missing breaks (thanks coverity)
  * Fix header copyright.
  * Fix a bug into the autorepeat trigger.
- Refresh patches:
  * libcaca-ruby_am_cflags.patch
  * libcaca-ruby_vendor_install.patch
* Mon Jan 22 2018 tchvatal@suse.com
- Fix URL
- Mention github repo containing more changes
- Format with spec-cleaner
- Remove support for older distros lets stick with latest only
- Remove for years disabled mono and java integration code snippets
- Use python macros to build python instead of waiting for autotools
- Convert to pkgconfig style dependencies
* Fri Mar 11 2016 hguo@suse.com
- Require imlib2-loaders in caca-utils package.
  All of the utilities fail to load any image without the dependency.
* Wed Sep  2 2015 dimstar@opensuse.org
- Add libcaca-ncurses6.patch: defined against a function name never
  worked, so set_escdelay was actually never used. With curses 6.0,
  though, ESCDELAY is no longer 'a variable', but a reference to a
  function, so we can't assign anything to it. We just assume that
  we always use a recent enough version of ncurses to have
  set_escdelay avaialble.
* Fri Mar 20 2015 dvlaeev@suse.com
- Build without Mono by default
  coolo says: "We don't want mono in Factory, if somebody needs it
  it should be set explicit (with_mono) per prjconf"
* Thu Mar 12 2015 dimstar@opensuse.org
- Update libcaca-ruby_vendor_install.patch: Use RbConfig::CONFIG
  instead of Config::Config to be compatible with ruby 2.2.
* Tue Feb 17 2015 p.drouand@gmail.com
- Update to version 0.99beta19
  * No changelog available
- Remove automake-1.12.patch; fixed on upstream release
* Thu Jan 15 2015 olaf@aepfle.de
- Remove __DATE__ usage from cacaclock
* Fri Oct  3 2014 crrodriguez@opensuse.org
- Add baselibs.conf as source to make factory-auto bot happy
* Wed Oct  1 2014 crrodriguez@opensuse.org
- Cleanup buildRequires, remove use of xorg-x11-*
* Thu Feb 20 2014 coolo@suse.com
- remove SUSE prefix from license
* Wed May 29 2013 mhrusecky@suse.cz
- fix build with different versions of ruby
* Sun Mar 17 2013 dmueller@suse.com
- add buildconditional to build optionally without mono
* Wed Jun  6 2012 cfarrell@suse.com
- license update: SUSE-WTFPL-2.0
  SPDX format (choose from http://www.spdx.org/licenses or the list linked
  at license.opensuse.org)
* Tue May 29 2012 puzel@suse.com
- fix build with automake-12.1
* Tue May 29 2012 jengelh@inai.de
- Use autoreconf instead of ./bootstrap since (a) that works,
  (b) avoids the inflexible handcrafted automake version check
* Mon May 14 2012 coolo@suse.com
- update to libcaca-0.99beta18
  - new "cacaclock" utility
  - improved FIGlet support
  - improved Python and Ruby bindings
  - numerous improvements and bugfixes
- fix build with ruby 1.9 and re-enable python support
* Sun Nov 13 2011 coolo@suse.com
- add libtool as explicit buildrequire to avoid implicit dependency
  from prjconf
* Tue Apr 12 2011 toddrme2178@gmail.com
- Add 32bit compatibility libraries
* Wed Jan 26 2011 davejplater@gmail.com
- Fix libcaca-devel Requires: libcaca-plugins to correct
  Requires: libcaca0-plugins.
* Sat Nov 20 2010 davejplater@gmail.com
- Update to libcaca-0.99beta17
- Removed patches: libcaca-no_slang_acsmap.patch for < 10.1
  libcaca-no_man3_pages.patch - pending investigation
  remove_badwords.patch - waiting for confirmation about bad words
  libcaca-0.99.beta16-libtool.patch - libtool method changed.
- Fixed patches : libcaca-ruby_am_cflags.patch,
  libcaca-ruby_vendor_install.patch, caca-no-build-date.patch
  and libcaca-0.99.beta16-missing-GLU.patch.
- Upstream changes : (See Changelog for more)
  * Add triangle texture mapping to NEWS and update ChangeLog.
  * Disable set_dither_palette until we really use it.
  * Fix distribution of Java source.
  * Large source code cleanup, getting rid of spaces, tabs, and svn keywords.
  * Nicer make check output for our custom tests.
  * Add missing ruby/test file to the distributed tarball.
  * Update logo in the PHP bindings.
  * Replace the old caca texture with a copy of our new logo.
  * Add #undef __extern at the end of caca0.h. Thanks to Carlo Bramini for
  * fixing this in #48.
  * Only define CACA_ALIAS with gcc > 3 (instead of >= 3). Patch courtesy of
  * Carlo Bramini. Addresses #48.
  * Add brief documentation to figfont functions.
  * Split check-build into check-doygen, check-source and check-win32.
  * Document file functions and fix a few issues here and there.
  * Move some configuration stuff from build-kernel into configure.ac.
  * Activate colour toilet font support.
  * Don't fail the check-build test if documentation was not built.
  * Simpler and more accurate troff colour selection.
  * Always draw all background in troff output, on beginning of lines too
  * Fix the source code to reduce testsuite errors.
  * Always draw all background in troff output
  * Fix check-build verbosity.
  * Fix shrext_cmds usage in configure.ac.
  * Map colors to the ones known by groff, defining mines don't work
  * Improve a bit troff export
  * Fix libcaca.a linkage (was off by one argument), fill memory with 0xCACA.
* Fri Nov 19 2010 coolo@novell.com
- disable pdf API reference documentation, it fails to build
  with newer doxygen and the html documentation should be enough
  for the package
* Mon Aug 30 2010 cristian.rodriguez@opensuse.org
- Do not include build date in binaries
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Mon Mar 16 2009 crrodriguez@suse.de
- fix build, missing -lGLU
- Update to version 0.99.beta16
- libcucul was merged back into libcaca for more clarity
- internal FIGlet font support
- use C99 types in public headers
- runtime support for output drivers
- BBcode export support
* Wed Jan 28 2009 crrodriguez@suse.de
- remove "la" files
* Thu Dec  4 2008 cfarrell@suse.de
- added patch to remove badwords because of bnc#441358
* Thu Jun 12 2008 pth@suse.de
- Build dynamic libraries, disable creation of static ones.
- Compile with OpenGL support.
- Install ruby bindings in vendorarch/vendorlib.
- Fix file list.
* Wed Feb 13 2008 pth@suse.de
- Update to 0.99beta13:
  - device-dependent cursor support
  - event API rewrite
  - Ruby bindings
  - Massive C# bindings improvements
  - Python sample code
  - support for 90-degree canvas rotation
  - better behaviour when trying to output Unicode on an ASCII terminal
  - the built-in font now supports the Geometric Shapes, Halfwidth and Fullwidth
  Forms and Miscellaneous Symbols Unicode blocks
  - new rotozoom effect in cacademo
  - preliminary .NET bindings
  - blitting canvases now makes use of the canvas' handle coordinates
  - import functions can read streamed data
  - attribute to colorspace transformations
  - added katakana and hiragana glyphs to the built-in font
  - support for blink, bold, italics and underline attributes
  - fixed Imlib2 support in cacaview
  - fixed buffer overflows in the file importer
  - support for fullwidth Unicode characters
  - transparency support in the UTF-8 importer and exporter
  - ANSI importer now handles transparency and UTF-8
  - various memory leaks were fixed
  - implemented cucul_getchar() and cucul_get_color()
  - handle transparency in the IRC export
  - new cropping and expanding filters
  - full Unicode support in the OpenGL driver
  - all demos except cacafire were merged into cacademo
  - added a compatibility layer for pre-1.x libcaca applications
  - libcaca functions use errno for error reporting
  - ANSI importer
  - cacadraw, an ANSI viewer that will evolve into an editor
  - Unicode input and output support for SLang and ncurses
  - license switched to WTFPL
  - libcaca was split into libcucul, a standalone text manipulation backend,
    and libcaca, the display and user input frontend
  - TrueColor (more than 16 colours) support
  - Floyd-Steinberg dithering
  - gamma correction
  - export functions for HTML, IRC, ANSI, SVG, PostScript, TGA...
  - builtin fonts for device-independent bitmap output
  - various text transformation routines (rotation, horizontal flip...)
  - OpenGL renderer
  - kernel mode to build libcaca programs into a bootable x86 kernel
  - cacaserver, a telnet server that can be hooked to libcaca applications
  - img2irc, an image to IRC conversion utility
* Sun Apr 22 2007 ro@suse.de
- use texlive for building
* Fri Mar 30 2007 rguenther@suse.de
- Add ncurses-devel BuildRequires.
* Fri Aug  4 2006 pth@suse.de
- Adapt to new X11 paths.
* Wed Mar 29 2006 pth@suse.de
- Fix BuildRequires.
* Wed Mar 29 2006 pth@suse.de
- Add X11 devel files to BuildRequires.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Dec 19 2005 ro@suse.de
- added missing manpage symlinks to filelist
* Fri Nov 25 2005 pth@suse.de
- Initial package.
  - undef clashing acs_map from slang.h
  - don't try to install non-existing man3 pages
  - install documentation to different directory
